aboutsummaryrefslogtreecommitdiff
path: root/build2/context.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2016-11-04 08:46:35 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2016-11-04 09:26:22 +0200
commit4b1f902b33d0826ccb2f6d5a1ceb8db7bdd2defe (patch)
tree9f0fcddb0b6cad34965a7ca330c3cd8b033c195d /build2/context.cxx
parent08aba2ee7cf407c9c25233ebbf43d0310e0f1b5e (diff)
Change token type 'name' to more general 'word'
Diffstat (limited to 'build2/context.cxx')
-rw-r--r--build2/context.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/build2/context.cxx b/build2/context.cxx
index 1527cc8..c783832 100644
--- a/build2/context.cxx
+++ b/build2/context.cxx
@@ -110,14 +110,14 @@ namespace build2
//
lexer l (is, path ("<cmdline>"), "\'\"\\$(");
// The first token should be a name, either the variable name or the
// scope qualification.
//
token t (l.next ());
token_type tt (l.next ().type);
dir_path dir;
- if (t.type == token_type::name && tt == token_type::colon)
+ if (t.type == token_type::word && tt == token_type::colon)
{
if (!path::traits::is_separator (t.value.back ()))
fail << "expected directory (with trailing slash) instead of "
@@ -136,7 +136,7 @@ namespace build2
// This should be the variable name followed by =, +=, or =+.
//
- if (t.type != token_type::name || t.value.empty () ||
+ if (t.type != token_type::word || t.value.empty () ||
(tt != token_type::assign &&
tt != token_type::prepend &&
tt != token_type::append))
@@ -110,14 +110,14 @@ namespace build2
//
lexer l (is, path ("<cmdline>"), "\'\"\\$(");
- // The first token should be a name, either the variable name or the
+ // The first token should be a word, either the variable name or the
// scope qualification.
//